/*
	Name		:	debug.rexx
	Created		:	24/06/96
	Last change	:	25/06/96

	Programmer	:	Urban Lindeskog
	Organization	:	ProNotion SWDG


	Creates a file with information about the CD drive
	and the system configuration.

	Reports about some potential errors in the settings.

*/
OPTIONS RESULTS

if ~show('l','rexxsupport.library') then do
	addlib('rexxsupport.library',0,-30,0)
end

say ''
say 'This program will create a file called "RexxCD.debuginfo"'
say 'If RexxCD have problems with your CD drive, please send'
say 'this file to me so I can resolve the problem.'
say ''

if ~show('p','REXXCD') then do
	say 'RexxCD is not running.'
	say 'Start RexxCD and try again.'
	say ''
	exit
end

ADDRESS REXXCD

if open(fh, "RexxCD.debuginfo", 'W') then do
	address REXXCD

	GETATTR APPLICATION STEM APPLICATION
	call writeln(fh, '<--APPLICATION-->')
	call writeln(fh, APPLICATION.VERSION)
	call writeln(fh, APPLICATION.SCREEN'<')

	GETATTR SETTINGS STEM SETTINGS
	call writeln(fh, '<--SETTINGS-->')
	call writeln(fh, SETTINGS.REPEAT)
	call writeln(fh, SETTINGS.ALLOWMACROS)
	call writeln(fh, SETTINGS.TOCPATH'<')

	GETATTR DEVICE STEM DEVICE
	call writeln(fh, '<--DEVICE-->')
	call writeln(fh, DEVICE.NAME'<')
	call writeln(fh, DEVICE.UNIT)

	GETATTR DRIVE STEM DRIVE
	call writeln(fh, '<--DRIVE-->')
	call writeln(fh, DRIVE.NAME'<')
	call writeln(fh, DRIVE.VENDOR'<')
	call writeln(fh, DRIVE.REVISION'<')
	call writeln(fh, DRIVE.PRIVATE'<')
	call writeln(fh, DRIVE.STATUS)
	call writeln(fh, DRIVE.TYPE)
	call writeln(fh, DRIVE.BPS)
	call writeln(fh, DRIVE.STEREO)

	GETATTR VOLUME STEM VOLUME
	call writeln(fh, '<--VOLUME-->')
	call writeln(fh, VOLUME.LEFT)
	call writeln(fh, VOLUME.RIGHT)
	call writeln(fh, '<---->')

	call close(fh)
	end
else do
	say 'Could not create "RexxCD.debuginfo"!'
	say 'Please check, and try again.'
	exit
	end

if DRIVE.TYPE ~= 5 then do
	say '---NOTE---'
	say 'This SCSI unit does not seem to be a CD ROM drive.'
	say ''
	end

if DRIVE.STATUS > 3 then do
	say '---NOTE---'
	say 'This unit reports an unknown status number.'
	say ''
	end

if DEVICE.NAME=='' then do
	say '---NOTE---'
	say 'It appears that the SCSI device name is not set'
	say ''
	end

if (DEVICE.UNIT < 0) | (DEVICE.UNIT > 6) then do
	say '---NOTE---'
	say 'The SCSI device unit number is out of the normal range (0-6)'
	say 'The SCSI controller often occupies unit 7'
	say ''
	end

if EXISTS(SETTINGS.TOCPATH)~=1 then do
	say '---NOTE---'
	say 'The path specified for the data files does not exist.'
	say ''
	end

if VOLUME.LEFT~=VOLUME.RIGHT then do
	say '---NOTE---'
	say 'The stereo volume pairs are not at equal levels.'
	say 'Some CD drives requires both controls to be the same.'
	say ''
	end

if (VOLUME.LEFT+VOLUME.RIGHT)==0 then do
	say '---NOTE---'
	say 'The volume controls are set to zero.'
	say 'This might explain something.'
	say ''
	end

if find(DRIVE.VENDOR, 'NEC')>0 then do
	say '---NOTE---'
	say 'This appears to be a NEC drive. Those drives seem'
	say 'to be some creatures of their own.'
	say ''
	end

